@@ -4,6 +4,7 @@ from .utils.io_container_data import IOContainerData
 from .banco_dados.conexao_banco import ConexaoBanco
 import pandas as pd
 import os
+import logging
 from multiprocessing.pool import ThreadPool
 
 class Start():
@@ -20,18 +21,18 @@ class Start():
 
     def start(self):
 
-        print(f"Arquivo {self.path_file}")
+        logging.info(f"Arquivo {self.path_file}")
 
         self.file_input_enrichment = self.__copy_input_enrichment()
 
 
     def enrichment(self, dictParametros ):
 
-        print(f"Iniciando o processa de tratamento do arquivo")
+        logging.info(f"Iniciando o processa de tratamento do arquivo")
 
-        print(f"Separador {self.sep}")
-        print(f"Posição do cabeçalho {self.header}")
-        print(f"Tipo de dado {self.dtype}")
+        logging.info(f"Separador {self.sep}")
+        logging.info(f"Posição do cabeçalho {self.header}")
+        logging.info(f"Tipo de dado {self.dtype}")
 
         df_data = self.ioContainerData.load(
                                 self.file_input_enrichment, 
@@ -45,15 +46,15 @@ class Start():
 
         extensao = self.ioContainerData.get_extension(self.file_input_enrichment)
 
-        print(f"Extensão do arquivo {extensao}")
+        logging.info(f"Extensão do arquivo {extensao}")
 
         if extensao == ".xlsx" or extensao == ".xls":
             try:
-                print(f"Iniciando o processo simples")
+                logging.info(f"Iniciando o processo simples")
                 self.dados_original = df_data
                 self.__processamento(dictParametros, True)
                 del(self.dados_original)
-                print(f"Final o processo simples\n")
+                logging.info(f"Final o processo simples\n")
                 
             except Exception as error:
                 raise Exception(f"Erro no processamento {error}")
@@ -66,7 +67,7 @@ class Start():
             for chunk in df_data:
         
                 try:
-                    print(f"Iniciando o processo do lote {count}")
+                    logging.info(f"Iniciando o processo do lote {count}")
 
                     if isinstance(chunk, pd.DataFrame)  :
                         self.dados_original = chunk
@@ -80,7 +81,7 @@ class Start():
 
                     del(chunk)
 
-                    print(f"Final o processo do lote {count}\n")
+                    logging.info(f"Final o processo do lote {count}\n")
 
                     count = count + 1    
                 except Exception as error:
@@ -88,7 +89,7 @@ class Start():
 
         del(df_data)
 
-        print("Fim do processo de enrichment")
+        logging.info("Fim do processo de enrichment")
 
 
     def __processamento(self, dictParametros, is_first_processing):
@@ -143,7 +144,7 @@ class Start():
             self.ioContainerData.name_container_bronze,
             self.ioContainerData.name_container_silver )
   
-        print(f'Arquivo movido para {file_input_enrichment}')
+        logging.info(f'Arquivo movido para {file_input_enrichment}')
 
         return file_input_enrichment
 
@@ -158,8 +159,7 @@ class Start():
                                       self.ioContainerData.name_container_silver, 
                                       self.ioContainerData.name_container_bronze 
                                     )
-        print(f'Arquivo salvo em backup {self.ioContainerData.name_container_bronze}/{backup}')
-
+        logging.info(f'Arquivo salvo em backup {self.ioContainerData.name_container_bronze}/{backup}')
 
 
     def fail(self):
@@ -174,14 +174,14 @@ class Start():
                                       self.ioContainerData.name_container_bronze 
                                     )
 
-        print(f'Arquivo salvo em falha {self.ioContainerData.name_container_bronze}/{failed}')
+        logging.info(f'Arquivo salvo em falha {self.ioContainerData.name_container_bronze}/{failed}')
 
 
     def __delete_lines(self, list_lines_delete):
 
         try:
             if(list_lines_delete != None):
-                print(f"Iniciando o processo de deleção das linhas")
+                logging.info(f"Iniciando o processo de deleção das linhas")
 
                 for lines_delete in list_lines_delete:
 
@@ -211,7 +211,7 @@ class Start():
         
         try:
             if(list_lines_duplicates != None):
-                print(f"Iniciando o processo de drop em linhas duplicadas")
+                logging.info(f"Iniciando o processo de drop em linhas duplicadas")
                 self.dados.drop_duplicates(list_lines_duplicates, inplace=True) 
                 if(is_first_processing == False):
 
@@ -258,7 +258,7 @@ class Start():
     
         try:
             if(list_columns_delete != None):
-                print(f"Iniciando o processo de deleção das colunas")
+                logging.info(f"Iniciando o processo de deleção das colunas")
                 self.dados.drop(columns=list_columns_delete, inplace=True, axis=1)
                 #for column in list_columns_delete:
                 #    if column in list(self.dados.columns):
@@ -274,9 +274,9 @@ class Start():
 
         try:
             if( list_field_reorganize != None ):
-                print(f"Iniciando processo de reorganização de colunas")
+                logging.info(f"Iniciando processo de reorganização de colunas")
                 self.dados = self.dados[list_field_reorganize]
-                print(f"Colunas reorganizadas para {list_field_reorganize}")
+                logging.info(f"Colunas reorganizadas para {list_field_reorganize}")
 
         except Exception as error:
             raise Exception(f"Erro ao reorganizar campos {error}")
@@ -286,14 +286,14 @@ class Start():
 
         try:
             if( list_column_formt_date != None):
-                print(f"Iniciando o processo de formatação das datas")
+                logging.info(f"Iniciando o processo de formatação das datas")
                 for column_formt_date in list_column_formt_date:
-                    print(f"Coluna da data {column_formt_date[1]}")
+                    logging.info(f"Coluna da data {column_formt_date[1]}")
                     try:
                         self.dados[ column_formt_date[0] ] = self.dados[ column_formt_date[1] ]\
                             .astype('datetime64[ns]').dt.strftime(column_formt_date[2])
                     except Exception as e:
-                        print(f"Erro no processo de conversão de data {e}")
+                        logging.info(f"Erro no processo de conversão de data {e}")
                         self.dados[ column_formt_date[0] ] = np.NaN
         except Exception as error:
             raise Exception(f"Erro ao formatar data {error}")
@@ -304,9 +304,9 @@ class Start():
         
         try:
             if(list_analytics != None and len(self.dados) > 0):
-                print(f"Iniciando o processo de aplicação de analise na coluna")
+                logging.info(f"Iniciando o processo de aplicação de analise na coluna")
                 for analytic in list_analytics:
-                    print(f"Coluna a ser analisada {analytic[0]}")
+                    logging.info(f"Coluna a ser analisada {analytic[0]}")
                     self.dados[analytic[0]] =  self.dados.apply(
                         lambda x: eval(compile(analytic[1], '<string>', 'eval')) ,axis=1)
         except Exception as error:
@@ -327,7 +327,7 @@ class Start():
                 path_out_file_enrichment, 
                 self.dados)
 
-            print(f'Arquivo movido para {path_out_file_enrichment}')
+            logging.info(f'Arquivo movido para {path_out_file_enrichment}')
             
         except Exception as error:
             raise Exception(f"Erro ao salvar dados enriquecido {error}")
@@ -349,7 +349,7 @@ class Start():
         try:
              self.conexaoBanco.close_connection()
         except Exception as error:
-            print (f"Erro ao fechar conexão com o banco {error}")
+            logging.error(f"Erro ao fechar conexão com o banco {error}")
 
     def __get_field(self,  field_columns) -> pd.DataFrame:
        
@@ -358,7 +358,7 @@ class Start():
                 return self.dados_original
             else:
                 if type(field_columns) is list :
-                    print(f"Iniciando o processo de recuperação das colunas")
+                    logging.info(f"Iniciando o processo de recuperação das colunas")
                     return self.dados_original.loc[:,field_columns]
                 else:
                     raise Exception(f"Erro atributo fileds deve ser um list")
@@ -371,7 +371,7 @@ class Start():
 
         try:
             if(list_parametros_enrichment_sql != None and len(list_parametros_enrichment_sql) > 0):
-                print(f"Iniciando de enriquecimento por sql")
+                logging.info(f"Iniciando de enriquecimento por sql")
                 for parametros in list_parametros_enrichment_sql:
 
                     if(parametros.left_query != None):
@@ -414,7 +414,7 @@ class Start():
 
         try:
             if(list_columns_rename != None):
-                print(f"Iniciando processo de renomeação de colunas")
+                logging.info(f"Iniciando processo de renomeação de colunas")
                 self.dados.rename(columns=list_columns_rename, inplace=True)
         except Exception as error:
             raise Exception(f"Erro ao renomear os campos {error}")
@@ -429,24 +429,26 @@ class Start():
 
             
 
-    def run(self, myDict):
+    def run(self, myDict)->str:
 
+        msg = ""
+        
         try:
-
             self.start()   
-
             self.enrichment(myDict)
-
             self.backup()
-
-            print(f"processamento finalizado com sucesso arquivo {self.path_file}")
+            logging.info(f"processamento finalizado com sucesso arquivo {self.path_file}")
+            msg = f"processamento finalizado com sucesso arquivo {self.path_file}"
         except Exception as e:
-            print(f"Falha no processo {e}")
+            logging.error(f"Falha no processo {e}")
+            msg = f"Falha no processo {e}"
             self.fail()
         finally:
             self.__close_base()
-            print("Fim do processo")
+            logging.info("Fim do processo")
+            msg = "Fim do processo"
 
+        return msg
 
 
     
\ No newline at end of file
